@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:addr.c,v 1.37 2000/09/29 21:18:00 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:addr.c,v 1.38 2001/07/28 18:05:02 woods Exp"
  */
 
 /*
@@ -161,7 +161,7 @@ preparse_address_1(address, error, rest)
 	ap = xmalloc((unsigned)(strlen(address) + 1));
 	strcpy(ap, address);
 	if (mark_end) {
-	    *mark_end++ = '>';		/* widden the original address */
+	    *mark_end++ = '>';		/* widen the original address */
 	}
 	DEBUG1(DBG_ADDR_HI, "preparse_address returns: %s\n", ap);
 	*rest = mark_end;
@@ -529,19 +529,21 @@ check_target_and_remainder(target, remainder)
     char **remainder;
 {
     int c;
-    char *p = *target;
+    char *p;
 
-    if ((*remainder)[0] == '\0') {
+    /*
+     * first check the remainder...
+     */
+    p = *remainder;
+    if (*p == '\0') {
 	*remainder = "no remainder address";
 	DEBUG1(DBG_ADDR_MID, "parse_address: %s\n", *remainder);
 	return FAIL;
     }
-    /* the set of chars in the target should be limited to a small set */
-    if (*p == '-') {
-	*remainder = "target cannot begin with `-'";
-	DEBUG2(DBG_ADDR_MID, "parse_address(%s): %s\n", p, *remainder);
-	return FAIL;
-    }
+    /*
+     * now check the target...
+     */
+    p = *target;
     if (*p == '[') {
 #ifdef HAVE_BSD_NETWORKING
 # if defined(INET_ADDR_USE_STRUCT)
@@ -571,8 +573,22 @@ check_target_and_remainder(target, remainder)
 #endif
 	return SUCCEED;
     }
+    if (*p == '-') {
+	*remainder = "target cannot begin with `-'";
+	DEBUG2(DBG_ADDR_MID, "parse_address(%s): %s\n", p, *remainder);
+	return FAIL;
+    }
+    /*
+     * this test is more in line with RFC-821's restrictions, which are based
+     * on RFC-1035's hostname restrictions.  Other transports may not be quite
+     * so restrictive as this (or may even be more restrictive!).
+     *
+     * WARNING: we should probably use something like CERT's IsValidHostname()
+     * to validate total length, length of each label, start char of each
+     * label, etc.
+     */
     while ((c = *p++)) {
-	if (!(isalnum(c) || c == '.' || c == '-' || c == '_' || c == '+' || c == '=')) {
+	if (!(isalnum(c) || c == '.' || c == '-')) {
 	    *remainder = "illegal character in hostname";
 	    DEBUG2(DBG_ADDR_MID, "parse_address(%s): %s\n", *target, *remainder);
 	    return FAIL;
