@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:bindlib.c,v 1.69 2000/11/03 23:30:51 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:bindlib.c,v 1.71 2001/07/29 23:11:31 woods Exp"
  */
 
 /*
@@ -247,6 +247,10 @@
 #include <errno.h>
 #include "defs.h"
 
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+
 /*
  * Compilation of this entire file depends on "HAVE_BIND".
  */
@@ -508,13 +512,13 @@ bind_check_if_canonical_host(hostnm, inet, error_p)
 	    if ((a_rr->rr_type == T_A) && (memcmp(a_rr->rr_data, (char *) &inet, sizeof(inet)) == 0)) {
 		result = DB_SUCCEED;	/* Oh!  I guess there was a matching A RR! */
 	    } else if (a_rr->rr_type == T_CNAME) {
-		*error_p = not_a_canonical_host(xprintf("the domain name '%s' is a CNAME not a hostname\\\n\t(it must be a domain name resolving to an A record)", hostnm));
+		*error_p = not_a_canonical_host(xprintf("the domain name '%s' is a CNAME not a hostname (it must be a domain name resolving to an A record)", hostnm));
 	    } /* we don't care about any other kind of RRs */
 	}
     }
     if (result != DB_SUCCEED && !*error_p) {
 	/* XXX we probably don't need the actual source address in here... */
-	*error_p = not_a_canonical_host(xprintf("no DNS A records for the hostname '%s' have a\\\n\ttarget address matching the source address [%s]",
+	*error_p = not_a_canonical_host(xprintf("no DNS A records for the hostname '%s' have a target address matching the source address [%s]",
 						hostnm,
 						inet_ntoa(*((struct in_addr *) &inet))));
     } else if (nothing) {
