@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:config.c,v 1.42 2000/09/03 17:17:05 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:config.c,v 1.44 2001/06/25 22:09:55 woods Exp"
  */
 
 /*
@@ -51,7 +51,7 @@ int log_mode = LOG_MODE;		/* mode for system log files */
 int message_log_mode = MESSAGE_LOG_MODE; /* mode for per-message log files */
 int spool_grade = SPOOL_GRADE;		/* default spool grade character */
 int open_retries = OPEN_RETRIES;	/* max open retries on config files */
-int open_interval = OPEN_INTERVAL;	/* sleep between open retries  */
+int open_interval = OPEN_INTERVAL;	/* sleep between open retries */
 int min_runq_grade;			/* minimum grade to process in queue run */
 int max_runq_grade;			/* maximum grade to process in queue run */
 int min_delivery_grade;			/* minimum grade to deliver */
@@ -61,8 +61,8 @@ char *director_file = DIRECTOR_FILE;	/* directors file name */
 char *router_file = ROUTER_FILE;	/* routers file name */
 char *method_dir = METHOD_DIR;		/* directory for non-/ method files */
 char *transport_file = TRANSPORT_FILE;	/* transports file name */
-char *qualify_file = QUALIFY_FILE;      /* domain qualification file name */
-char *retry_file = RETRY_FILE;          /* address retry control file name */
+char *qualify_file = QUALIFY_FILE;	/* domain qualification file name */
+char *retry_file = RETRY_FILE;		/* address retry control file name */
 char *smail_lib_dir = SMAIL_LIB_DIR;	/* default config file directory */
 char *smail_util_dir = SMAIL_UTIL_DIR;	/* default smail utility directory */
 char *received_field = RECEIVED_FIELD;	/* Received: field string */
@@ -100,7 +100,7 @@ int smtp_accept_queue = SMTP_ACCEPT_QUEUE; /* simultaneous SMTPs to queueonly */
 char *smtp_banner = SMTP_BANNER;	/* smtp startup banner message */
 int smtp_allow_debug = SMTP_ALLOW_DEBUG; /* allow DEBUG command in SMTP */
 int smtp_allow_expn = SMTP_ALLOW_EXPN;	/* allow EXPN commanda in SMTP */
-char *smtp_recipient_no_verify = SMTP_RECIPIENT_NO_VERIFY; /* ip list for not verifying RCPT TO  */
+char *smtp_recipient_no_verify = SMTP_RECIPIENT_NO_VERIFY; /* ip list for not verifying RCPT TO: */
 char *smtp_remote_allow = SMTP_REMOTE_ALLOW; /* ip list that can send remote smtp */
 int smtp_hello_verify = SMTP_HELLO_VERIFY; /* verify HELO/EHLO host has A RR matching sockaddr */
 char *smtp_hello_broken_allow = SMTP_HELLO_BROKEN_ALLOW; /* ip list that can avoid hello verification */
@@ -110,11 +110,14 @@ int smtp_hello_verify_literal = SMTP_HELLO_VERIFY_LITERAL; /* verify HELO/EHLO d
 int smtp_hello_verify_ptr = SMTP_HELLO_VERIFY_PTR; /* verify HELO/EHLO matches PTR RR for sockaddr */
 char *smtp_rbl_domains = SMTP_RBL_DOMAINS; /* list of RBL domains */
 char *smtp_rbl_except = SMTP_RBL_EXCEPT; /* list of exceptions to RBL lookups */
-char *smtp_sender_no_verify = SMTP_SENDER_NO_VERIFY; /* ip list for not verifying MAIL FROM  */
+char *smtp_sender_no_verify = SMTP_SENDER_NO_VERIFY; /* ip list for not verifying MAIL FROM: */
+char *smtp_sender_rhsbl_domains = SMTP_SENDER_RHSBL_DOMAINS; /* list of RHSBL domains for sender addresses */
+char *smtp_sender_rhsbl_except = SMTP_SENDER_RHSBL_EXCEPT; /* list of exceptions to sender RHSBL lookups */
 int smtp_sender_verify_mx_only = SMTP_SENDER_VERIFY_MX_ONLY; /* require MX RRs for MAIL FROM: hosts */
 int smtp_max_recipients = SMTP_MAX_RECIPIENTS; /* maximum recipients per SMTP connect */
 unsigned int smtp_expn_delay = SMTP_EXPN_DELAY;	/* seconds to delay after an EXPN command */
 unsigned int smtp_vrfy_delay = SMTP_VRFY_DELAY;	/* seconds to delay after a VRFY command */
+unsigned int smtp_error_delay = SMTP_ERROR_DELAY; /* seconds to delay after any SMTP error */
 unsigned int debug_pause_for_smtp_connections = 0; /* seconds to pause after child fork for debugger connect */
 char *sender_env_variable = SENDER_ENV_VARIABLE; /* env variable naming user */
 int switch_percent_and_bang = SWITCH_PERCENT_AND_BANG;
