@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:config.h,v 1.75 2001/02/05 23:27:10 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:config.h,v 1.77 2001/06/25 22:09:55 woods Exp"
  */
 
 /*
@@ -739,7 +739,7 @@ ${if and{{origin:local} {def:owner}}\
  * SMTP startup banner message
  */
 #ifndef SMTP_BANNER
-# define SMTP_BANNER "$primary_name Smail-$version (#$compile_num $compile_date) ready at $date"
+# define SMTP_BANNER "$primary_name Smail-$version (#$compile_num $compile_date)\nready at $date"
 #endif
 
 /*
@@ -909,6 +909,25 @@ ${if and{{origin:local} {def:owner}}\
 # define SMTP_SENDER_VERIFY_MX_ONLY	0 	/* XXX give the benefit of doubt */
 #endif
 
+/*
+ * The default list of RHSBLs
+ */
+#ifndef SMTP_SENDER_RHSBL_DOMAINS
+# define SMTP_SENDER_RHSBL_DOMAINS	NULL
+#endif
+
+/*
+ * The default list of networks which will not trigger an RHSBL lookup.
+ */
+
+#ifndef SMTP_SENDER_RHSBL_EXCEPT
+# if defined(HAVE_LIBWHOSON)
+#  define SMTP_SENDER_RHSBL_EXCEPT	"localnet:whoson" /* special */
+# else
+#  define SMTP_SENDER_RHSBL_EXCEPT	"localnet" /* special */
+# endif
+#endif
+
 /*
  * maximum recipients per SMTP connect
  */
@@ -933,6 +952,14 @@ ${if and{{origin:local} {def:owner}}\
 # define SMTP_VRFY_DELAY		5	/* prevent dictionary attacks by default */
 #endif
 
+/*
+ * seconds to delay after ANY smtp "error" (4xx or 5xx response)
+ */
+
+#ifndef SMTP_ERROR_DELAY
+# define SMTP_ERROR_DELAY		5	/* prevent immediate reconnects */
+#endif
+
 /*
  * Timeout of directors and routers for multiple defers
  *
