@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:default.c,v 1.54 2001/02/05 23:27:11 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:default.c,v 1.55 2001/06/23 03:42:38 woods Exp"
  */
 
 /*
@@ -919,8 +919,7 @@ static struct transport local_transport = {
     "pipe",				/* use the pipe driver */
     SUCC,				/* point to next transport */
     /* put Received:, Return-Path:, will do local delivery */
-    PUT_RECEIVED | PUT_RETURNPATH | LOCAL_TPORT | LOCAL_XFORM | /* LOCAL_XFORM? really???? */
-	PIPE_STATUS_2SENDER,
+    PUT_RECEIVED | PUT_RETURNPATH | STRICT_TPORT | LOCAL_TPORT | PIPE_STATUS_2SENDER,
 # ifdef	LOCAL_MAIL_ADDRS
     /* if there is a specific limit on number of addrs from config.h,
      * use that in assigning transport instances, otherwise limit is 1,
@@ -959,7 +958,7 @@ static struct transport local_transport = {
     "appendfile",			/* use the appendfile driver */
     SUCC,				/* point to next transport */
     /* put Received:, Return-Path: and From_ line, will do local delivery */
-    PUT_RECEIVED | PUT_RETURNPATH | LOCAL_TPORT | LOCAL_XFORM | PUT_FROM |
+    PUT_RECEIVED | PUT_RETURNPATH | STRICT_TPORT | LOCAL_TPORT | PUT_FROM |
 	APPEND_AS_USER |		/* use uid/gid from addr structure */
 	APPEND_CHECK_USER |		/* make sure $user is safe (no /) */
 #if (!defined(UNIX_SCO) || defined(NO_MMDF_MAILBOXES)) && !defined(MMDF_MAILBOXES)
@@ -1002,7 +1001,7 @@ static struct transport pipe_transport = {
     "pipe",				/* use the pipe driver */
     SUCC,				/* point to next transport */
     /* put Recieved:, Return-Path: and From_ line, will do local delivery */
-    PUT_RECEIVED | PUT_RETURNPATH | LOCAL_TPORT | LOCAL_XFORM | PUT_FROM |
+    PUT_RECEIVED | PUT_RETURNPATH | STRICT_TPORT | LOCAL_TPORT | PUT_FROM |
 	UNIX_FROM_HACK |
 	PIPE_AS_USER | PIPE_PARENT_ENV | PIPE_LOG_OUTPUT | PIPE_STATUS_2SENDER,
     1, 1, 0,				/* 1 addr, 1 host, size not useful */
@@ -1042,7 +1041,7 @@ static struct transport file_transport = {
     "appendfile",			/* use the apppendfile driver */
     SUCC,				/* point to next transport */
     /* put Recieved:, Return-Path: and From_ line, will do local delivery */
-    PUT_RECEIVED | PUT_RETURNPATH | LOCAL_TPORT | LOCAL_XFORM | PUT_FROM |
+    PUT_RECEIVED | PUT_RETURNPATH | STRICT_TPORT | LOCAL_TPORT | PUT_FROM |
 #if (!defined(UNIX_SCO) || defined(NO_MMDF_MAILBOXES)) && !defined(MMDF_MAILBOXES)
 	UNIX_FROM_HACK |
 # endif
