@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:expand.c,v 1.33 2000/09/11 01:19:55 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:expand.c,v 1.34 2001/07/30 02:41:24 woods Exp"
  */
 
 /*
@@ -70,7 +70,7 @@ static char *quote_fold __P((char *));
 static char *shell_quote_fold __P((char *));
 static char *skip_ident __P((char *, char *));
 static int skip_nesting __P((char **));
-static int clause_token __P((char **, char **, int*));
+static int clause_token __P((char **, char **, unsigned int *));
 #ifndef NODEBUG
 static void bad_subst __P((char *, unsigned int));
 #endif
@@ -578,7 +578,7 @@ lookup_clause(addr, str, s, es)
     char *xproto = NULL;
     char *xfile = NULL;
     unsigned int key_len;
-    int proto_len, file_len;
+    unsigned int proto_len, file_len;
     char *then_clause, *then_end, *else_clause, *else_end;
     struct str file_str;
     char *dbinfo;
@@ -1459,7 +1459,7 @@ static int
 clause_token(sp, startp, lenp)
     char **sp;
     char **startp;
-    int *lenp;
+    unsigned int *lenp;
 {
     char *s = *sp;
 
