@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:extern.h,v 1.78 2001/01/18 00:31:32 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:extern.h,v 1.82 2001/07/29 16:10:48 woods Exp"
  */
 
 /*
@@ -23,7 +23,7 @@ extern int errno;			/* previous system error value */
  */
 /* external variables defined in alloc.c */
 extern struct block *perm;		/* permanent allocation block */
-extern int x_dont_panic;                /* dont panic in X_CHECK() */
+extern int x_dont_panic;		/* dont panic in X_CHECK() */
 
 /* external variables defined in config.c */
 extern char *listen_name;		/* DNS name of interface to listen on */
@@ -58,8 +58,8 @@ extern char *director_file;		/* directors file name */
 extern char *router_file;		/* routers file name */
 extern char *method_dir;		/* directory for non-/ method files */
 extern char *transport_file;		/* transports file name */
-extern char *qualify_file;              /* domain qualification file name */
-extern char *retry_file;                /* address retry control file name */
+extern char *qualify_file;		/* domain qualification file name */
+extern char *retry_file;		/* address retry control file name */
 extern char *smail_lib_dir;		/* default config file directory */
 extern char *smail_util_dir;		/* default smail utility directory */
 extern char *received_field;		/* Received: field string */
@@ -97,7 +97,7 @@ extern int smtp_accept_max;		/* max simultaneous SMTPs to accept */
 extern int smtp_accept_queue;		/* simultaneous SMTPs until queueonly */
 extern int smtp_allow_debug;		/* allow DEBUG command in SMTP */
 extern int smtp_allow_expn;		/* allow EXPN command in SMTP */
-extern char *smtp_recipient_no_verify;	/* ip list for not verifying RCPT TO  */
+extern char *smtp_recipient_no_verify;	/* ip list for not verifying RCPT TO: */
 extern char *smtp_remote_allow;		/* ip list that can send remote smtp */
 extern char *smtp_local_net;		/* the local network calculated from src. addr */
 extern int smtp_hello_verify;		/* verify HELO/EHLO host has A RR matching sockaddr */
@@ -108,11 +108,14 @@ extern int smtp_hello_verify_literal;	/* verify HELO/EHLO domain literal has PTR
 extern int smtp_hello_verify_ptr;	/* verify HELO/EHLO matches PTR RR for sockaddr */
 extern char *smtp_rbl_domains;		/* list of RBL domains */
 extern char *smtp_rbl_except;		/* list of exceptions to RBL lookups */
-extern char *smtp_sender_no_verify;	/* ip list for not verifying MAIL FROM */
+extern char *smtp_sender_no_verify;	/* ip list for not verifying MAIL FROM: */
+extern char *smtp_sender_rhsbl_domains;	/* list of RHSBL domains for sender addresses */
+extern char *smtp_sender_rhsbl_except;	/* list of exceptions to sender RHSBL lookups */
 extern int smtp_sender_verify_mx_only;	/* require MX RRs for MAIL FROM: hosts */
 extern int smtp_max_recipients;		/* maximum recipients per SMTP connect */
 extern unsigned int smtp_expn_delay;	/* seconds to delay after an EXPN command */
 extern unsigned int smtp_vrfy_delay;	/* seconds to delay after a VRFY command */
+extern unsigned int smtp_error_delay;	/* seconds to delay after any SMTP error */
 extern unsigned int debug_pause_for_smtp_connections; /* seconds to pause after child fork for debugger connect */
 extern char *sender_env_variable;	/* env variable naming user */
 extern int switch_percent_and_bang;	/* switch precedence of % and ! */
@@ -125,6 +128,7 @@ extern unsigned int smtp_receive_message_timeout; /* timeout for receiving SMTP
 extern char *auth_domains;		/* authoritative domain list */
 extern long rfc1413_query_timeout;	/* Timeout on RFC1413 queries - initially disabled */
 extern long resolve_timeout;		/* timeout on directors/routers */
+extern int scan_frozen;			/* should mailq look in the error queue? */
 
 /* external variables defined in copyright.c */
 extern char copyright[];		/* the program copyright notice */
@@ -252,6 +256,7 @@ extern int cached_transports;		/* TRUE if cache_transports() called */
 
 /* external variables defined in smtprecv.c */
 extern char *sender_host_really;	/* result of PTR lookup */
+extern long accepted_msg_size;		/* size we're currently willing to accept */
 
 
 /*
@@ -318,7 +323,7 @@ extern char **read_message __P((void));
 extern int write_body __P((FILE *, long));
 extern void check_grade __P((void));
 extern void log_incoming __P((void));
-extern char **scan_spool_dirs __P((void));
+extern char **scan_spool_dirs __P((int));
 extern int swallow_smtp __P((FILE *));
 
 /* external functions defined in resolve.c */
