@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:lookup.c,v 1.53 2000/09/29 21:20:07 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:lookup.c,v 1.57 2001/07/30 02:41:24 woods Exp"
  */
 
 /*
@@ -149,7 +149,7 @@ static int lsearch_open __P((char *, struct proto *, int, unsigned int, struct s
 static void lsearch_close __P((struct generic_db *));
 static int lsearch_lookup __P((struct generic_db *, char *, char **, char **));
 #ifdef USE_LSEARCH_REGEXCMP
-static int lsearch_regexcmp __P((char *, char *, int *));
+static int lsearch_regexcmp __P((char *, char *, unsigned int *));
 #endif
 
 static int dbmbase_open __P((char *, struct proto *, int, unsigned int, struct stat *, char **, char **));
@@ -357,10 +357,10 @@ bsearch_open(name, proto, retries, interval, statp, db, error)
 	    if ((f = fopen(name, "r"))) break;
 	}
 	if (f == NULL) {
+	    *error = strerror(errno);
 	    if (errno == ENOENT) {
 		return FILE_NOMATCH;
 	    }
-	    *error = strerror(errno);
 	    return FILE_FAIL;
 	}
     }
@@ -555,13 +555,15 @@ lsearch_open(name, proto, retries, interval, statp, db, error)
 	while (left-- > 0) {
 	    DEBUG2(DBG_DRIVER_HI, "lsearch_open: will retry open(%s) after %d seconds\n", name, interval);
 	    (void) sleep(interval);
-	    if ((f = fopen(name, "r"))) break;
+	    if ((f = fopen(name, "r"))) {
+		break;
+	    }
 	}
 	if (f == NULL) {
+	    *error = strerror(errno);
 	    if (errno == ENOENT) {
 		return FILE_NOMATCH;
 	    }
-	    *error = strerror(errno);
 	    return FILE_FAIL;
 	}
     }
@@ -608,7 +610,7 @@ static int
 lsearch_regexcmp(entry, key, len)
     char *entry;
     char *key;
-    int *len;
+    unsigned int *len;
 {
     static int inited = FALSE;
     static struct str exp;
@@ -877,9 +879,10 @@ dbmbase_open(name, proto, retries, interval, statp, db, error)
 	    }
 	}
 	if (succeed != DB_SUCCEED) {
-	    if (errno == ENOENT)
-		return FILE_NOMATCH;
 	    *error = strerror(errno);
+	    if (errno == ENOENT) {
+		return FILE_NOMATCH;
+	    }
 	    return FILE_FAIL;
 	}
     }
@@ -1083,8 +1086,8 @@ yp_open(name, proto, retries, interval, statp, db, error)
     register struct yp_db *priv;
     register char *p, *pname;
     int err;				/* error from yp functions */
-#if defined(__svr4__) && defined(__sun__)	/* Solaris-2.x */
-    unsigned long order;		/* output from yp_order */
+#if (defined(__SVR4) && defined(__sun)) || (defined(__svr4__) && defined(__sun__))
+    unsigned long order;		/* output from yp_order Solaris-2.x */
 #else  /* *BSD and the rest */
     int order;				/* output from yp_order */
 #endif
@@ -1880,6 +1883,10 @@ match_ip(ip, patterns, fldsep, msgsep, reasonp)
     char *end_p;
     unsigned int len;
     
+    if (!patterns) {
+	return 0;
+    }
+
     /* run through the pattern list */
     for (pat_p = patterns; /* NOTEST */ ; pat_p = end_p + 1) {
 
