@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:main.c,v 1.68 2001/01/18 00:31:32 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:main.c,v 1.70 2001/07/29 16:10:48 woods Exp"
  */
 
 /*
@@ -119,6 +119,7 @@ char *sender_host_addr = NULL;		/* inet address of sender's host */
 char *sender_proto = NULL;		/* name of sender's sending protocol */
 char *sender_program = NULL;		/* name of program that spooled msg */
 char *smtp_service_name = NULL;		/* smtp service name from -oX */
+int scan_frozen = FALSE;		/* should mailq look in the error queue? */
 
 /* functions local to this file */
 static void panic_if_null __P((char *, char *));
@@ -996,6 +997,10 @@ process_args(args, restrict)
 		    debug = 1;
 		break;
 
+	    case 'E':
+		scan_frozen = TRUE;
+		break;
+
 	    case 'V':
 		operation_mode = PRINT_VERSION;
 		break;
@@ -1437,6 +1442,7 @@ process_args(args, restrict)
 		    }
 		    switch (*arg) {
 
+		    case 'e':		/* used by 4.4bsd rmail for: no errors, just status */
 		    case 'm':
 			error_processing = MAIL_BACK;
 			break;
@@ -1623,6 +1629,13 @@ process_args(args, restrict)
 	    num_recipients++;
 	}
     }
+    if (scan_frozen && operation_mode != PRINT_QUEUE) {
+	if (errfile) {
+	    (void) fprintf(errfile, "%s: cannot process frozen message (error) queue.  (try `unfreezemail')\n", program);
+	}
+	exit(EX_USAGE);
+	/* NOTREACHED */
+    }
 }
 
 static unsigned int
