@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:modes.c,v 1.106 2001/02/05 23:18:11 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:modes.c,v 1.110 2001/07/29 23:54:29 woods Exp"
  */
 
 /*
@@ -199,7 +199,7 @@ build_host_strings()
 	    /*NOTREACHED*/
 	}
 
-	if ((s = index(real_hostname, '.')) != NULL) {
+	if ((s = strchr(real_hostname, '.')) != NULL) {
 	    *s++ = '\0';
 	    real_domain = s;
 	}
@@ -244,7 +244,7 @@ build_host_strings()
     /* primary_name is always the first hostname value */
     primary_name = hostnames;
 
-    s = index(hostnames, ':');
+    s = strchr(hostnames, ':');
     if (s) {
 	/* In ANSI C string literals can be put in unwritable text space.
 	 * Thus, rather than just put a nul byte to separate primary_name
@@ -261,6 +261,13 @@ build_host_strings()
     if (visible_name == NULL) {
 	visible_name = primary_name;
     }
+
+    /*
+     * XXX We REALLY need to validate hostnames here, especially if we're doing
+     * any outbound SMTP as RFC 821 et al put certain limitations on the syntax
+     * of valid hostnames.....  (eg. no underscores or other funny stuff,
+     * various total and label length limits, etc.)
+     */
 }
 
 /*
@@ -908,7 +915,7 @@ daemon_mode()
     struct sockaddr_in sockin, from;	/* from is currently  */
     struct servent *smtp_service;	/* smtp service file entry */
     struct hostent *hostentp;		/* host file entry */
-    int port;
+    unsigned int port;
     int accept_err_cnt = 0;
 #ifdef ISC_ACCEPT_BUG
     int nsel;
@@ -941,7 +948,7 @@ daemon_mode()
 	smtp_service_name = "smtp";
     }
     if (isdigit(smtp_service_name[0])) {
-	port = htons(atoi(smtp_service_name));
+	port = htons((unsigned int) atoi(smtp_service_name));
     } else {
 	if ((smtp_service = getservbyname(smtp_service_name, "tcp")) == NULL) {
 	    write_log(WRITE_LOG_SYS, "%s/tcp: unknown service", smtp_service_name);
@@ -1347,7 +1354,7 @@ daemon_mode()
 /*ARGSUSED*/
 static void
 daemon_sighup(sig)
-    int sig;
+    int sig;					/* UNUSED */
 {
     /*
      * XXX note that pause() won't re-awaken on SIGHUP -- should we use
@@ -1363,7 +1370,7 @@ daemon_sighup(sig)
 /*ARGSUSED*/
 static void
 daemon_sigterm(sig)
-    int sig;
+    int sig;					/* UNUSED */
 {
     write_log(WRITE_LOG_SYS, "SIGTERM received, shutting down daemon.");
     exit(EX_OK);
@@ -1376,7 +1383,7 @@ daemon_sigterm(sig)
 /*ARGSUSED*/
 static void
 daemon_sigchld(sig)
-    int sig;
+    int sig;					/* UNUSED on UNIX_BSD */
 {
     int pid;
 
@@ -1421,7 +1428,7 @@ int pid;
 /*ARGSUSED*/
 static void
 daemon_sigalrm(sig)
-    int sig;
+    int sig;					/* UNUSED */
 {
     got_sigalrm = TRUE;
     (void) signal(SIGALRM, daemon_sigalrm);
@@ -1779,7 +1786,7 @@ do_run_queue()
 	 * directory we could avoid reading the whole queue just to see if this
 	 * one spool file exists....
 	 */
-	work = scan_spool_dirs();
+	work = scan_spool_dirs(FALSE);
 	if (! *work) {
 	    if (errfile) {
 		(void)fprintf(errfile,
@@ -1798,7 +1805,7 @@ do_run_queue()
      * If we're either handling all the queue entries, or several queue
      * entries, then build the work list, and do it with child processes....
      */
-    work = scan_spool_dirs();
+    work = scan_spool_dirs(FALSE);
     while (*work) {
 	if (errfile) {
 	    (void) fflush(errfile);
@@ -1897,13 +1904,15 @@ print_queue()
     int col = 0;			/* current print column */
     unsigned int numjobs = 0;
     unsigned long jobsize = 0;
+    unsigned int altjobs = 0;
+    unsigned long altsize = 0;
 
     X_PANIC_OKAY();
 
-    if (message_bufsiz > 4096) {
-	message_bufsiz = 4096;		/* don't need a big buffer */
+    if (message_bufsiz > BUFSIZ) {
+	message_bufsiz = BUFSIZ;	/* don't need a big buffer */
     }
-    work = scan_spool_dirs();
+    work = scan_spool_dirs(scan_frozen);
 
     while (*work) {
 	char **argv;			/* arguments from spool file */
@@ -1911,7 +1920,7 @@ print_queue()
 	/* open without locking */
 	if (open_spool(*work, FALSE, WRITE_LOG_TTY) == FAIL) {
 	    /* just ignore the file if it's already gone missing... */
-	    if (exitvalue != EX_NOINPUT) {
+	    if (exitvalue != EX_NOINPUT && exitvalue != EX_SOFTWARE && exitvalue != EX_OSFILE) {
 		write_log(WRITE_LOG_TTY|WRITE_LOG_SYS,
 			  "print_queue: %s/%s: lock failed (this can't happen -- we didn't ask to lock!): [%d] %s",
 			  spool_dir, input_spool_fn, exitvalue,
@@ -1931,9 +1940,10 @@ print_queue()
 	    continue;
 	}
 
-	(void) printf("%s\tFrom: %s  (in %s/input)\n",
+	(void) printf("%s\tFrom: %s  (in %s/%s)\n",
 		      message_id,
-		      sender, spool_dir);
+		      sender, spool_dir,
+		      scan_frozen ? "error" : "input");
 
 	(void) printf("\t\tDate: %s\n", get_arpa_date(message_date()));
 
@@ -1959,7 +1969,7 @@ print_queue()
 		col++;
 	    }
 	    col += strlen(*argv);
-	    if (strlen(*argv) == 0 || index(*argv, ' ') != NULL) {
+	    if (strlen(*argv) == 0 || strchr(*argv, ' ') != NULL) {
 		col += 2;
 		printf("'%s'", *argv++);
 	    } else {
@@ -1978,16 +1988,63 @@ print_queue()
 	    putchar('\n');
 	}
     }
-
-    if (numjobs || jobsize) {		/* pedantic, but... */
-	printf("\nSmail mail queue %s: %u job%s, %lu byte%s.\n",
+    if (numjobs || jobsize) {		/* pedantic, but safe and robust... */
+	printf("\nSmail %s queue %s: %u job%s, %lu byte%s.\n",
+	       scan_frozen ? "frozen (error)" : "mail",
 	       recipients ? "matching entries" : "stats",
 	       numjobs, numjobs > 1 ? "s" : "",
 	       jobsize, jobsize > 1 ? "s" : "");
     } else if (recipients) {
-	printf("No matching entries in Smail mail queue.\n");
+	printf("No matching entries in Smail %s queue.\n", scan_frozen ? "frozen (error)" : "mail");
     } else {
-	printf("Smail mail queue is empty.\n");
+	printf("Smail %s queue is empty.\n", scan_frozen ? "frozen (error)" : "mail");
+    }
+
+    /*
+     * now we'll scan the other queue just to get the sub-totals for it
+     */
+    scan_frozen = !scan_frozen;			/* ARGH!  I hate global variables! */
+    work = scan_spool_dirs(scan_frozen);
+
+    while (*work) {
+	/* open without locking */
+	if (open_spool(*work, FALSE, WRITE_LOG_TTY) == FAIL) {
+	    /* just ignore the file if it's already gone missing... */
+	    if (exitvalue != EX_NOINPUT && exitvalue != EX_SOFTWARE && exitvalue != EX_OSFILE) {
+		write_log(WRITE_LOG_TTY|WRITE_LOG_SYS,
+			  "print_queue: %s/%s: lock failed (this can't happen -- we didn't ask to lock!): [%d] %s",
+			  spool_dir, input_spool_fn, exitvalue,
+			  exitvalue == EX_TEMPFAIL ? "already locked" : "(unknown error)");
+	    }
+	    work++;
+	    continue;
+	}
+	sender = NULL;
+	if (!read_message()) {
+	    if (msg_size == 0 && debug) {
+		printf("%s/%s: empty spool file, ignored...\n", spool_dir, input_spool_fn);
+	    } else if (msg_size != 0) {
+		printf("%s/%s: incomplete spool file, ignored...\n", spool_dir, input_spool_fn);
+	    }
+	    work++;
+	    continue;
+	}
+	altjobs++;
+	altsize += msg_size;
+	close_spool();
+	work++;				/* next assignment */
+    }
+    if (altjobs || altsize) {		/* pedantic, but safe and robust... */
+	printf("Smail %s queue %s: %u job%s, %lu byte%s. (print with%s -E)\n",
+	       scan_frozen ? "frozen (error)" : "mail",
+	       recipients ? "matching entries" : "stats",
+	       altjobs, altjobs > 1 ? "s" : "",
+	       altsize, altsize > 1 ? "s" : "",
+	       scan_frozen ? "" : "out" );
+    } else if (recipients) {
+	printf("No matching entries in Smail %s queue.\n", scan_frozen ? "frozen (error)" : "mail");
+    } else {
+	printf("Smail %s queue is empty.\n", scan_frozen ? "frozen (error)" : "mail");
     }
 
     return;
