@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:notify.c,v 1.43 2001/01/18 00:31:33 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:notify.c,v 1.45 2001/06/23 03:43:27 woods Exp"
  */
 
 /*
@@ -359,7 +359,7 @@ error_delivery(addr)
 		      cur->next_addr ? cur->next_addr : cur->in_addr,
 		      top ? " (orig-to " : "",
 		      top ? top->in_addr : "",
-		      top ? ")");
+		      top ? ")" : "");
 #endif
 	} else if (cur->error) {
 	    if (cur->error->info & ERR_NSENDER) {
@@ -1264,7 +1264,7 @@ write_notify_header(f)
     bzero(&addr, sizeof(addr));
     addr.transport = &tport;
     tport.name = "error";
-    tport.flags = PUT_RECEIVED | LOCAL_XFORM;
+    tport.flags = PUT_RECEIVED | STRICT_TPORT;
     write_header(f, &addr);
 }
 
