@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:parse.c,v 1.10 2000/11/03 23:28:36 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:parse.c,v 1.11 2001/07/29 23:11:32 woods Exp"
  */
 
 /*
@@ -34,6 +34,11 @@
 #include <errno.h>
 #include <ctype.h>
 #include "defs.h"
+
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+
 #include "smail.h"
 #include "main.h"
 #include "parse.h"
