@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:queue.c,v 1.46 2000/09/03 17:00:15 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:queue.c,v 1.48 2001/07/29 16:10:48 woods Exp"
  */
 
 /*
@@ -146,6 +146,9 @@ queue_message(f, dusage, list, error)
  *
  * This is used to read in a complete message from an SMTP transaction
  * which will not be using because of some error.
+ *
+ * XXX perhaps this should count bytes and add them to msg_size so that we can
+ * tell how much the client was hoping to send.
  */
 int
 swallow_smtp(f)
@@ -369,6 +372,7 @@ queue_message_internal(f, dusage, error)
     char **error;			/* optionally store error here */
 {
     if (dusage == NO_DOT_PROTOCOL) {
+	*error = NULL;
 	return queue_message_simple(f);
     }
     return queue_message_with_dots(f, dusage, error);
@@ -1269,7 +1273,8 @@ log_incoming()
  * subsequent calls to scan_spool_dirs().
  */
 char **
-scan_spool_dirs()
+scan_spool_dirs(frozen)
+    int frozen;				/* look for frozen messages instead? */
 {
     static char **mv = NULL;		/* vector of messages */
     unsigned int mc = 0;		/* count of messages */
@@ -1290,7 +1295,7 @@ scan_spool_dirs()
     /* loop through all spool directories looking for work */
     for (dn = strcolon(spool_dirs); dn; dn = strcolon((char *)NULL)) {
 	char *fn;			/* filename from directory */
-	char *in_dn = xprintf("%s/input", dn);
+	char *in_dn = xprintf(frozen ? "%s/error" : "%s/input", dn);
 
 	DEBUG1(DBG_QUEUE_HI, "scan_spool_dirs() looking in %s\n", in_dn);
 
