@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:smailconf.c,v 1.53 2001/01/18 07:36:07 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:smailconf.c,v 1.57 2001/07/29 23:11:32 woods Exp"
  */
 
 /*
@@ -25,6 +25,11 @@
 #include <errno.h>
 #include <ctype.h>
 #include "defs.h"
+
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+
 #include "smail.h"
 #include "main.h"
 #include "log.h"
@@ -156,10 +161,13 @@ static struct attr_table conf_attributes[] = {
     { "smtp_rbl_domains", t_string, NULL, (tup *)&smtp_rbl_domains, 0 },
     { "smtp_rbl_except", t_string, NULL, (tup *)&smtp_rbl_except, 0 },
     { "smtp_sender_no_verify", t_string, NULL, (tup *)&smtp_sender_no_verify, 0 },
+    { "smtp_sender_rhsbl_domains", t_string, NULL, (tup *)&smtp_sender_rhsbl_domains, 0 },
+    { "smtp_sender_rhsbl_except", t_string, NULL, (tup *)&smtp_sender_rhsbl_except, 0 },
     { "smtp_sender_verify_mx_only", t_boolean, NULL, (tup *)&smtp_sender_verify_mx_only, 0 },
     { "smtp_max_recipients", t_int, NULL, (tup *)&smtp_max_recipients, 0 },
     { "smtp_expn_delay", t_int, NULL, (tup *)&smtp_expn_delay, 0 },
     { "smtp_vrfy_delay", t_int, NULL, (tup *)&smtp_vrfy_delay, 0 },
+    { "smtp_error_delay", t_int, NULL, (tup *)&smtp_error_delay, 0 },
     { "debug_pause_for_smtp_connections", t_int, NULL, (tup *)&debug_pause_for_smtp_connections, 0},
     { "spool_dirs", t_string, NULL, (tup *)&spool_dirs, 0 },
     { "spool_dir", t_string, NULL, (tup *)&spool_dir, 0 },
@@ -298,8 +306,8 @@ read_config_file(fn)
 	    }
 	}
 
-#if 0
-	convert_value(conf_attr->type, value, (char **) &(sp + t->offset), "variable");
+#if 0 /* XXX this code is mostly duplicated in fill_attributes() */
+	convert_value(conf_attr->type, value, (char **) conf_attr->uptr, "variable");
 #else
 	switch (conf_attr->type) {
 	case t_string:
@@ -1006,7 +1014,7 @@ fill_attributes(sp, attrs, flags, attr_table, end_attr_table)
 	}
 
 	/* fill in the attribute */
-#if 0
+#if 0 /* XXX this code is mostly duplicated in read_config_file() */
 	convert_value(t->type, value, (char **) &(sp + t->offset), "attribute");
 #else
 	switch (t->type) {
