@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:smailconf.h,v 1.8 2000/09/03 16:26:32 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:smailconf.h,v 1.9 2001/07/30 02:41:24 woods Exp"
  */
 
 /*
@@ -36,7 +36,7 @@ struct attr_table {
     char *value;			/* value to put in config file */
     union u_attr {
 	char *v_string;			/* string variable */
-	int  v_boolean;			/* boolean variable */
+	unsigned int  v_boolean;	/* boolean variable */
 	int  v_char;			/* char variable, accessed as int */
 	int  v_int;			/* integer variable */
 	long v_long;			/* long variable */
@@ -44,7 +44,7 @@ struct attr_table {
 	char *(*v_proc) __P((void));	/* procedure to handle attribute */
 	char *(*v_infoproc) __P((void)); /* procedure for info attribute */
     } *uptr;				/* point to configuration variable */
-    long offset;			/* offset into data structure */
+    unsigned long offset;		/* offset into data structure */
 };
 
 /* convenience typedef for use in initializing conf_form tables */
