@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:spool.c,v 1.33 2001/01/18 00:31:33 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:spool.c,v 1.36 2001/07/29 16:10:48 woods Exp"
  */
 
 /*
@@ -32,6 +32,7 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <sys/types.h>
+#include <sys/param.h>
 #include <sys/stat.h>
 #include <errno.h>
 #include <signal.h>
@@ -54,6 +55,20 @@
 #include "debug.h"
 #include "extern.h"
 
+#ifdef HAVE_STATVFS
+# include <sys/statvfs.h>			/* SysVr4 & SUSv2 */
+#else /* assume HAVE_STATFS */
+# ifdef HAVE_SYS_STATFS_H
+#  include <sys/statfs.h>			/* SysVr3 */
+# else
+#  ifdef HAVE_SYS_VFS_H
+#   include <sys/vfs.h>				/* ??? */
+#  else
+#   include <sys/mount.h>			/* just 4.4BSD? */
+#  endif
+# endif
+#endif
+
 #if defined(POSIX_OS) || !defined(UNIX_BSD)
 # include <time.h>
 #else
@@ -853,6 +868,12 @@ write_spool()
     }
     msg_size += msg_max - msg_buf;
 
+    if (accepted_msg_size >= 0 && msg_size >= accepted_msg_size) {
+	DEBUG1(DBG_SPOOL_LO,
+	      "write_spool: message grew bigger than allowed [%ld]\n", accepted_msg_size);
+	return FAIL;
+    }
+
     return SUCCEED;
 }
 
@@ -976,19 +997,19 @@ open_spool(fn, lock, logopts)
 	/* allocate the spool i/o buffer if it does not yet exist */
 	msg_buf = xmalloc(message_bufsiz);
     }
-    msg_max = msg_buf;			/* start at beginning of buffer */
+    msg_max = msg_buf;				/* start at beginning of buffer */
     end_msg_buf = msg_buf + message_bufsiz;
     if (fn[0] != '/') {
 	write_log(logopts, "open_spool: %s: filename not absolute", fn);
 	exitvalue = EX_SOFTWARE;
 	return FAIL;
     }
-    spool_dir = fn;		/* get directory from fn */
-    spool_fn = rindex(fn, '/');		/* get basename from fn */
+    spool_dir = fn;				/* get directory from fn */
+    spool_fn = strrchr(fn, '/');		/* get basename from fn */
     input_spool_fn = spool_fn - sizeof("/input") + 1;
     spool_fn++;
     if (input_spool_fn < spool_dir ||
-	strncmp(input_spool_fn, "/input", sizeof("/input") - 1))
+	strncmp(input_spool_fn, scan_frozen ? "/error" : "/input", sizeof("/input") - 1))
     {
 	write_log(logopts, "open_spool failed: %s: invalid spool filename",
 		  spool_dir);
@@ -1668,64 +1689,90 @@ message_date()
     }
     return clck;
 }
-
 
-#ifdef HAVE_DF_SPOOL
-#ifdef HAVE_STATVFS
-#include <sys/statvfs.h>
-#else /* not HAVE_STATVFS */
-#ifdef HAVE_SYS_STATFS_H
-#include <sys/statfs.h>
-#else /* not HAVE_SYS_STATFS_H */
-#include <sys/vfs.h>
-#endif /* not HAVE_SYS_STATFS_H */
-#endif /* not HAVE_STATVFS */
+#if defined(HAVE_STATFS) || defined(HAVE_STATVFS)
 
 long
-spool_max_free_space ()
+spool_max_free_space()
 {
     char *dirs = spool_dirs;
     char dirname[SIZE_FILNAM];
     char *p;
-    long max_free_bytes = -1, free_bytes;
-    int result;
-#ifdef HAVE_STATVFS
+    long max_free_bytes = -1;
+    long free_bytes;			/* free space in a given spool_dir */
+    long reserved;			/* amount of free space to reserve */
+    int result;				/* stat*fs() return code */
+# ifdef HAVE_STATVFS
     struct statvfs buf;
-#else
+# else
     struct statfs buf;
-#endif
+# endif
 
+    if (max_message_size > 0) {
+	    /* leave 2MB for logs, etc., plus max incoming messages */
+	    reserved = (2*1024*1024) + (smtp_accept_max * max_message_size);
+    } else {
+	    /*
+	     * just round out to a conservative 2MB plus 1MB per potential
+	     * incoming message....  (it would be better to leave a certain
+	     * percentage free, but to do that we'd have to add another spool.c
+	     * function to calculate the total size of the spool_dirs
+	     * filesystems)
+	     */
+	    reserved = (2 + smtp_accept_max) * 1024 * 1024;
+    }
     while (dirs && *dirs) {
-	for (p = dirname; *dirs && *dirs != ':'; *p++ = *dirs++) ;
+	for (p = dirname; *dirs && *dirs != ':'; *p++ = *dirs++) {
+		;
+	}
 	if (*dirs == ':') {
 	    /* next try gets the next directory */
 	    dirs++;
 	}
 	*p++ = '\0';			/* terminate directory name */
-#ifdef HAVE_STATVFS
-	result = statvfs (dirname, &buf);
-#else
-	result = statfs (dirname, &buf, sizeof buf, 0);
-#endif
-	if (result == -1)
+# ifdef HAVE_STATVFS
+	result = statvfs(dirname, &buf);
+# else
+#  ifdef BSD					/* 4.4 only? */
+	result = statfs(dirname, &buf);
+#  else
+	/* AT&T UNIX SysVr3 and clones */
+	result = statfs(dirname, &buf, sizeof(buf), 0);
+#  endif
+# endif
+	if (result == -1) {
 	    continue;
-#ifdef HAVE_STATVFS
+	}
+# ifdef HAVE_STATVFS
 	free_bytes = buf.f_bfree * buf.f_frsize;
-#else
+# else
+#  ifdef BSD
+	free_bytes = buf.f_bavail * buf.f_bsize;
+#  else
 	free_bytes = buf.f_bfree * buf.f_bsize;
-#endif
-	if (free_bytes > max_free_bytes)
+#  endif
+# endif
+	if (free_bytes > max_free_bytes) {
 	    max_free_bytes = free_bytes;
+	}
     }
-    return max_free_bytes;
+    max_free_bytes -= reserved;
+
+    return ((max_free_bytes < 0) ? 0 : max_free_bytes);
 }
-#else /* not HAVE_DF_SPOOL */
+
+#else /* not HAVE_STAT*FS */
+
+/*
+ * XXX we don't (yet?) support ancient systems with ustat(2) only...
+ */
 long
-spool_max_free_space ()
+spool_max_free_space()
 {
     return -1;
 }
-#endif /* not HAVE_DF_SPOOL */
+
+#endif /* HAVE_STAT*FS */
 
 #ifdef STANDALONE
 
