@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:string.c,v 1.34 2000/09/29 22:13:35 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:string.c,v 1.36 2001/07/30 02:40:42 woods Exp"
  */
 
 /*
@@ -43,7 +43,7 @@ extern char lowcase[];			/* lower case conversion table */
 extern char upcase[];			/* upper case conversion table */
 #endif /* STANDALONE */
 
-#if (__STDC__ - 0) > 0
+#ifdef __STDC__
 # include      <stdarg.h>
 # define VA_START(args, lastarg)       va_start(args, lastarg)
 #else
@@ -208,6 +208,8 @@ strcolon(s)
  * given a string and a colon separated list of strings, return TRUE
  * if the given string is in the list, else FALSE.  Case is not
  * significant in comparisons.
+ *
+ * XXX might be nice to add ';' subfield handling ala match_ip()
  */
 int
 is_string_in_list(string, list)
@@ -307,7 +309,7 @@ strsysexit(exitcode)
  * note that we only support %s, %d, %o, %x and %c.  Also support
  * a %z which inserts a null byte (support %N for backward compatibility).
  */
-#if ((__STDC__ - 0) > 0)
+#ifdef __STDC__
 void
 str_printf(struct str *sp, char *fmt, ...)
 #else
@@ -437,7 +439,7 @@ bltoa(base, n)
  * xprintf - str_print to a region, returning pointer to xmalloc()ed region
  * that should be xfree()ed when finished with....
  */
-#if ((__STDC__ - 0) > 0)
+#ifdef __STDC__
 char *
 xprintf(char *fmt, ...)
 #else
@@ -470,7 +472,7 @@ xprintf(fmt, va_alist)
  *
  * XXX using two fixed args with va_list is potential trouble....
  */
-#if ((__STDC__ - 0) > 0)
+#ifdef __STDC__
 int
 dprintf(FILE *file, char *fmt, ...)
 #else
