@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:transport.c,v 1.34 2000/09/29 22:14:21 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:transport.c,v 1.35 2001/06/23 03:43:48 woods Exp"
  */
 
 /*
@@ -91,7 +91,7 @@ static struct attr_table transport_generic[] = {
     { "received", t_boolean, NULL, NULL, PUT_RECEIVED },
     { "return_path", t_boolean, NULL, NULL, PUT_RETURNPATH },
     { "from", t_boolean, NULL, NULL, PUT_FROM },
-    { "local", t_boolean, NULL, NULL, LOCAL_TPORT|LOCAL_XFORM },
+    { "local", t_boolean, NULL, NULL, LOCAL_TPORT },
     { "local_xform", t_boolean, NULL, NULL, LOCAL_XFORM },
     { "crlf", t_boolean, NULL, NULL, PUT_CRLF },
     { "bsmtp", t_boolean, NULL, NULL, BSMTP_TPORT },
