@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/transports:RELEASE-3_2_0_112:appendfile.c,v 1.38 2000/09/11 01:20:56 woods Exp"
+#ident	"@(#)smail/src/transports:RELEASE-3_2_0_113:appendfile.c,v 1.39 2001/07/29 23:11:32 woods Exp"
  */
 
 /*
@@ -73,7 +73,13 @@
 #include <pwd.h>
 #include <grp.h>
 #include <sys/stat.h>
+
 #include "defs.h"
+
+#if defined(HAVE_PATHS_H) || defined (UNIX_BSD)
+# include <paths.h>
+#endif
+
 #if defined(UNIX_SYS5) || defined(POSIX_OS)
 # include <fcntl.h>
 #endif
@@ -120,6 +126,10 @@
 # define SEEK_END	2	/* set file offset to EOF plus offset */
 #endif
 
+#ifndef _PATH_DEVNULL
+# define _PATH_DEVNULL	"/dev/null"
+#endif
+
 /* functions local to this file */
 static void get_appendfile_ugid __P((struct transport *, struct addr *, int *, int *));
 static time_t get_atime __P((char *));
@@ -341,13 +351,13 @@ tpd_appendfile(addr, succeed, defer, fail)
     }
 
     /* get the user id and group id */
-    get_appendfile_ugid(tp, addr, &uid, &gid);
+    get_appendfile_ugid(tp, addr, (int *) &uid, (int *) &gid);
 
     /*
      * special case /dev/null, and don't do any more if dont_deliver
      * is set
      */
-    if (dont_deliver || EQ(fn, "/dev/null")) {
+    if (dont_deliver || EQ(fn, _PATH_DEVNULL)) {
 	insert_addr_list(addr, succeed, (struct error *)NULL);
 	return;
     }
