@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/transports:RELEASE-3_2_0_112:pipe.c,v 1.29 2000/09/03 17:00:25 woods Exp"
+#ident	"@(#)smail/src/transports:RELEASE-3_2_0_113:pipe.c,v 1.30 2001/07/29 23:11:32 woods Exp"
  */
 
 /*
@@ -232,7 +232,7 @@ tpd_pipe(addr, succeed, defer, fail)
     pipe_env = get_pipe_env(tp, addr);
 
     /* get the user id and group id */
-    get_pipe_ugid(tp, addr, &uid, &gid);
+    get_pipe_ugid(tp, addr, (int *) &uid, (int *) &gid);
 
     /*
      * if we are logging output, tie the output to the per-message log file
