@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src/transports:RELEASE-3_2_0_112:smtplib.c,v 1.46 2000/10/02 03:14:06 woods Exp"
+#ident	"@(#)smail/src/transports:RELEASE-3_2_0_113:smtplib.c,v 1.48 2001/07/29 23:11:32 woods Exp"
  */
 
 /*
@@ -12,9 +12,10 @@
 
 /*
  * smtplib.c:
- *	Send mail using the SMTP protocol.  This soure file is a set
- *	of library routines that can be used by transport drivers that
- *	can handle creating the virtual circuit connections.
+ *	Send mail using the SMTP protocol.  This soure file is a set of library
+ *	routines that can be used by transport drivers that can handle creating
+ *	the virtual circuit connections.  Some of these routines are also used
+ *	in ../smtprecv.c.
  *
  * A NOTE ABOUT SMTP ERROR LOGGING:
  *
@@ -32,6 +33,10 @@
 #include <signal.h>
 #include <ctype.h>
 #include "defs.h"
+
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
 #if defined(POSIX_OS)
 # include <unistd.h>
 #else /* not POSIX_OS */
@@ -597,6 +602,7 @@ smtp_send(smtpb, addr, succeed, defer, fail, defer_failure, error_p)
     struct addr *next;			/* next addr to send */
     struct addr *okay = NULL;		/* partially successful addrs */
     int local_owner = FALSE;            /* TRUE if owner is local */
+    char *local_part;
     struct transport *tp = smtpb->tp;
 
     if (! smtp_init_flag) {
@@ -627,9 +633,15 @@ smtp_send(smtpb, addr, succeed, defer, fail, defer_failure, error_p)
 		   addr->owner &&
 		   !strchr(addr->owner, '@'));
 
+    /*
+     * Note we must not send local parts that would violate RFC 821 so we have
+     * to quote it as necessary.  We'll do this always whether we use the value
+     * or not just to keep the logic here simple...
+     */
+    local_part = quote_local_part(((addr->owner) ? addr->owner : get_sender_addr(tp)));
+
     str_printf(&smtp_out, "MAIL FROM:<%s%s%s>",
-               (error_sender ? ((islocal && tp->flags & LOCAL_XFORM) ? "+" : "") :
-		(addr->owner) ? addr->owner : get_sender_addr(tp)),
+               error_sender ? ((islocal && tp->flags & LOCAL_XFORM) ? "+" : "") : local_part,
                local_owner ? "@" : "",
                local_owner ? visible_name : "");
 
@@ -698,7 +710,7 @@ smtp_send(smtpb, addr, succeed, defer, fail, defer_failure, error_p)
 	 *  5xx - failure	       (return message to sender)
 	 */
 	STR_CLEAR(&smtp_out);
-	str_printf(&smtp_out, "RCPT TO:<%s>", cur->next_addr);
+	str_printf(&smtp_out, "RCPT TO:<%s>", quote_local_part(cur->next_addr));
 
 	reply = write_command_maybe_wait(smtpb, smtpb->long_timeout,
 					 STR(&smtp_out), (int) STR_LEN(&smtp_out),
@@ -1275,11 +1287,183 @@ read_response_internal(smtpb, timeout, reply_text)
     return reply_code;
 }
 
+
+/*
+ *	is_dot_string() - is a string compliant with RFC 821 dot-string?
+ *
+ * in RFC 821 a dot-string must not contain any <special> or <SP>, other than
+ * "." of course, unless it's escaped with a "\", and with no double "."s and
+ * no trailing "." either:
+ *
+ *          <dot-string> ::= <string> | <string> "." <dot-string>
+ *
+ *          <string> ::= <char> | <char> <string>
+ *
+ *          <char> ::= <c> | "\" <x>
+ *
+ *          <SP> ::= the space character (ASCII code 32)
+ *
+ *          <c> ::= any one of the 128 ASCII characters, but not any
+ *                    <special> or <SP>
+ *
+ *          <x> ::= any one of the 128 ASCII characters (no exceptions)
+ *
+ *          <special> ::= "<" | ">" | "(" | ")" | "[" | "]" | "\" | "."
+ *                    | "," | ";" | ":" | "@"  """ | the control
+ *                    characters (ASCII codes 0 through 31 inclusive and
+ *                    127)
+ *
+ * Note that we don't care about finding quoted-strings inside strings because
+ * RFC 821 doesn't allow that, at least not for local-part (which is the only
+ * place it allows quoted-string anyway).
+ *
+ * Note the new RFC 2821 (which replaces 821) seems to concur with these rules.
+ */
+int
+is_dot_string(s)
+    char *s;
+{
+    int c;
+
+    while ((c = *s++)) {
+	if (c == '\\') {
+	    s++;				/* anything goes! */
+	    continue;
+	}
+	if (c == '<' || c == '>' || c == '(' || c == ')' || c == '[' || c == ']' ||
+	    c == '\\' || c == ',' || c == ';' || c == ':' || c == '@' || c == '"' ||
+	    c == ' ' || (c == '.' && *s == '.') || iscntrl(c)) {
+	    return FALSE;
+	}
+    }
+    if (*(s-2) == '.') {
+	return FALSE;
+    }
+
+    return TRUE;
+}
+
+/*
+ *	is_quoted_string() - is a string compliant with RFC 821 quoted-string?
+ *
+ * in RFC-821 a quoted local part may be any one of the 128 ASCII
+ * characters except <CR>, <LF>, quote ("), or backslash (\);
+ * unless it's escaped with a "\":
+ *
+ *          <quoted-string> ::=  """ <qtext> """
+ *
+ *          <qtext> ::=  "\" <x> | "\" <x> <qtext> | <q> | <q> <qtext>
+ *
+ *          <CR> ::= the carriage return character (ASCII code 13)
+ *
+ *          <LF> ::= the line feed character (ASCII code 10)
+ *
+ *          <q> ::= any one of the 128 ASCII characters except <CR>,
+ *                    <LF>, quote ("), or backslash (\)
+ *
+ *          <x> ::= any one of the 128 ASCII characters (no exceptions)
+ */
+int
+is_quoted_string(s)
+    char *s;
+{
+    int c;
+
+    if (*s++ != '"') {
+	return FALSE;
+    }
+    while ((c = *s++)) {
+	if (c == '\\') {
+	    s++;				/* anything goes! */
+	    continue;
+	}
+	if (c == '\r' || c == '\n' || c == '\\') {
+	    return FALSE;
+	}
+    }
+    if (*(s-2) != '"') {
+	return FALSE;
+    }
+
+    return TRUE;
+}
+
+/*
+ *	make_quoted_string() - make quoted-string from local-part
+ *
+ * Put quotes around `s', and insert a backslash before characters that need
+ * quoting when they part of a quoted-string.
+ *
+ * `at' might point to a domain-part, and if so we tack that onto the end.
+ */
+char *
+make_quoted_string(s, at)
+    char *s;
+    char *at;
+{
+    static struct str dst;
+    static int dst_inited = FALSE;		/* TRUE if str inited */
+    char *cp;
+    int ch;
+
+    if (! dst_inited) {
+	STR_INIT(&dst);
+	dst_inited = TRUE;
+    } else {
+	STR_CHECK(&dst);
+	STR_CLEAR(&dst);
+    }
+    STR_NEXT(&dst, '"');
+    for (cp = s; (ch = *cp); cp++) {
+        if (ch > 127 || ch == '\r' || ch == '\n' || ch == '"' || ch == '\\') {
+            STR_NEXT(&dst, '\\');
+	}
+        STR_NEXT(&dst, ch);
+    }
+    STR_NEXT(&dst, '"');
+    if (at) {
+	STR_CAT(&dst, at);
+    }
+    STR_DONE(&dst);
+
+    return STR(&dst);
+}
+
+
+/*
+ *	quote_local_part() - quote local part of address according to rfc 821
+ *
+ * According to RFC 821, a local-part is a dot-string or a quoted-string.
+ * We first see if the local-part is a dot-string.  If it is not, we turn
+ * it into a quoted-string. Anything else would be too painful.
+ *
+ * `lp' might be just a mailbox, or might be a fully qualified address....
+ */
+char *
+quote_local_part(lp)
+    char *lp;
+{
+    char *at = NULL;
+
+    if ((at = strchr(lp, '@'))) {
+	*at = '\0';
+    }
+    if (!is_dot_string(lp)) {
+	lp = make_quoted_string(lp, at ? at++ : (char *) NULL);
+    }
+    if (at) {
+	*at = '@';
+    }
+
+    return lp;
+}
+
+
 /* catch_timeout - longjmp after an alarm */
 /* ARGSUSED */
 static void
 catch_timeout(signo)
-	int	signo;			/* UNUSED */
+    int signo;					/* UNUSED */
 {
     JUMP_LONGJMP(timeout_buf, 1);
 }
