@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_112:smtplib.h,v 1.12 2000/10/01 18:39:42 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_113:smtplib.h,v 1.13 2001/07/28 17:37:01 woods Exp"
  */
 
 /*
@@ -73,3 +73,7 @@ struct smtp {
 extern int smtp_startup __P((struct smtp *, struct error **, int));
 extern int smtp_send __P((struct smtp *, struct addr *, struct addr **, struct addr **, struct addr **, int, struct error **));
 extern void smtp_shutdown __P((struct smtp *));
+extern int is_dot_string __P((char *));
+extern int is_quoted_string __P((char *));
+extern char *make_quoted_string __P((char *, char *));
+extern char *quote_local_part __P((char *));
