@@ -1,6 +1,6 @@
 #! /bin/sh
 :
-#ident	"@(#)smail/util:RELEASE-3_2_0_112:checkerr.sh,v 1.17 2000/11/03 23:36:03 woods Exp"
+#ident	"@(#)smail/util:RELEASE-3_2_0_113:checkerr.sh,v 1.18 2001/07/29 19:49:40 woods Exp"
 #
 #    Copyright (C) 1987, 1988 Ronald S. Karr and Landon Curt Noll
 #    Copyright (C) 1992  Ronald S. Karr
@@ -21,11 +21,11 @@ SMAIL_PROGRAM="X_SMAIL_NAME_X"
 SPOOL_DIRS="`$SMAIL_PROGRAM -bP spool_dirs`"
 TMPDIR="X_TMP_DIR_X"
 if [ ! -d $TMPDIR ] ; then
-	if ! mkdir $TMPDIR ; then
+	if mkdir $TMPDIR ; then
+		chmod 700 $TMPDIR
+	else
 		echo "$0: $TMPDIR exists as a file!" 2>&1
 		exit 1
-	else
-		chmod 700 $TMPDIR
 	fi
 fi
 HOSTNAME="`$SMAIL_PROGRAM -bP primary_name`"
