@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/util:RELEASE-3_2_0_112:mksort.c,v 1.9 2000/09/03 17:00:27 woods Exp"
+#ident	"@(#)smail/util:RELEASE-3_2_0_113:mksort.c,v 1.10 2001/07/29 20:13:24 woods Exp"
  */
 
 /*
@@ -139,8 +139,8 @@ cmp(a, b)
     const void *a;
     const void *b;
 {
-    char *s1 = (char *) a;
-    char *s2 = (char *) b;
+    char *s1 = *(char **) a;
+    char *s2 = *(char **) b;
     register int c1, c2;
 
     for (;;) {
@@ -163,8 +163,8 @@ cmpic(a, b)
     const void *a;
     const void *b;
 {
-    char *s1 = (char *) a;
-    char *s2 = (char *) b;
+    char *s1 = *(char **) a;
+    char *s2 = *(char **) b;
     register int c1, c2;
 
     for (;;) {
